# Sathwik Semester Results

Python package to fetch CMR semester results.

## Install

pip install sathwik-sem-results

## Usage

from sathwik_sem_results import fetch_results

df = fetch_results(["25R01A0476", "25R01A0477"])
print(df)

df.to_excel("results.xlsx", index=False)